@@ -1,7 +1,7 @@
 /*
  * Copyright © 2008 Alexander “weej” Jones <alex@weej.com>
  * Copyright © 2008 Thomas Perl <thp@perli.net>
- * 
+ *
  * Licensed under the GNU General Public License Version 2
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,8 +18,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* This is a "flash" object that you can create and invoke a method "flash" on to 
-   flood the screen with white temporarily */
+/* This is a "flash" object that you can create and invoke a method "flash" on to
+ * flood the screen with white temporarily */
 
 #include <gtk/gtk.h>
 
@@ -44,7 +44,7 @@ G_DEFINE_TYPE (CheeseFlash, cheese_flash, G_TYPE_OBJECT);
 
 typedef struct
 {
-  GtkWindow* window;
+  GtkWindow *window;
   guint flash_timeout_tag;
   guint fade_timeout_tag;
 } CheeseFlashPrivate;
@@ -66,27 +66,28 @@ cheese_flash_window_expose_event_cb (GtkWidget *widget, GdkEventExpose *event, g
 static void
 cheese_flash_init (CheeseFlash *self)
 {
-  CheeseFlashPrivate* priv = CHEESE_FLASH_GET_PRIVATE (self);
-  GtkWindow* window;
+  CheeseFlashPrivate *priv = CHEESE_FLASH_GET_PRIVATE (self);
+
+  GtkWindow *window;
 
   priv->flash_timeout_tag = 0;
-  priv->fade_timeout_tag = 0;
+  priv->fade_timeout_tag  = 0;
 
   window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL));
 
   /* make it so it doesn't look like a window on the desktop (+fullscreen) */
-  gtk_window_set_decorated (window, FALSE);  
+  gtk_window_set_decorated (window, FALSE);
   gtk_window_set_skip_taskbar_hint (window, TRUE);
   gtk_window_set_skip_pager_hint (window, TRUE);
   gtk_window_fullscreen (window);
   gtk_window_set_keep_above (window, TRUE);
-    
+
   /* Don't take focus */
   gtk_window_set_accept_focus (window, FALSE);
 
   /* Don't consume input */
   gtk_widget_realize (GTK_WIDGET (window));
-  GdkRegion* input_region;
+  GdkRegion *input_region;
   input_region = gdk_region_new ();
   gdk_window_input_shape_combine_region (GTK_WIDGET (window)->window, input_region, 0, 0);
   gdk_region_destroy (input_region);
@@ -98,7 +99,8 @@ cheese_flash_init (CheeseFlash *self)
 static void
 cheese_flash_dispose (GObject *object)
 {
-  CheeseFlashPrivate* priv = CHEESE_FLASH_GET_PRIVATE (object);
+  CheeseFlashPrivate *priv = CHEESE_FLASH_GET_PRIVATE (object);
+
   g_object_unref (priv->window);
 
   if (G_OBJECT_CLASS (cheese_flash_parent_class)->dispose)
@@ -115,26 +117,26 @@ cheese_flash_finalize (GObject *object)
 static void
 cheese_flash_class_init (CheeseFlashClass *klass)
 {
-  GObjectClass* object_class = G_OBJECT_CLASS (klass);
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (CheeseFlashPrivate));
 
-  object_class->dispose = cheese_flash_dispose;
+  object_class->dispose  = cheese_flash_dispose;
   object_class->finalize = cheese_flash_finalize;
 }
 
 static gboolean
 cheese_flash_opacity_fade (gpointer data)
 {
-  CheeseFlash* flash = data;
-  CheeseFlashPrivate* flash_priv = CHEESE_FLASH_GET_PRIVATE (flash);
-  GtkWindow* flash_window = flash_priv->window;
-  double opacity = gtk_window_get_opacity (flash_window);
+  CheeseFlash        *flash        = data;
+  CheeseFlashPrivate *flash_priv   = CHEESE_FLASH_GET_PRIVATE (flash);
+  GtkWindow          *flash_window = flash_priv->window;
+  double              opacity      = gtk_window_get_opacity (flash_window);
 
   /* exponentially decrease */
   gtk_window_set_opacity (flash_window, opacity * FLASH_FADE_FACTOR);
-    
-  if (opacity <= FLASH_LOW_THRESHOLD) 
+
+  if (opacity <= FLASH_LOW_THRESHOLD)
   {
     /* the flasher has finished when we reach the quit value */
     gtk_widget_hide (GTK_WIDGET (flash_window));
@@ -147,12 +149,12 @@ cheese_flash_opacity_fade (gpointer data)
 static gboolean
 cheese_flash_start_fade (gpointer data)
 {
-  CheeseFlash* flash = data;
-  CheeseFlashPrivate* flash_priv = CHEESE_FLASH_GET_PRIVATE (flash);
-  GtkWindow* flash_window = flash_priv->window;
-    
+  CheeseFlashPrivate *flash_priv = CHEESE_FLASH_GET_PRIVATE (CHEESE_FLASH (data));
+
+  GtkWindow *flash_window = flash_priv->window;
+
   /* If the screen is non-composited, just hide and finish up */
-  if (!gdk_screen_is_composited (gtk_window_get_screen (flash_window))) 
+  if (!gdk_screen_is_composited (gtk_window_get_screen (flash_window)))
   {
     gtk_widget_hide (GTK_WIDGET (flash_window));
     return FALSE;
@@ -163,10 +165,11 @@ cheese_flash_start_fade (gpointer data)
 }
 
 void
-cheese_flash_fire (CheeseFlash* flash)
+cheese_flash_fire (CheeseFlash *flash)
 {
-  CheeseFlashPrivate* flash_priv = CHEESE_FLASH_GET_PRIVATE (flash);
-  GtkWindow* flash_window = flash_priv->window;
+  CheeseFlashPrivate *flash_priv = CHEESE_FLASH_GET_PRIVATE (flash);
+
+  GtkWindow *flash_window = flash_priv->window;
 
   if (flash_priv->flash_timeout_tag > 0)
     g_source_remove (flash_priv->flash_timeout_tag);
@@ -175,12 +178,11 @@ cheese_flash_fire (CheeseFlash* flash)
 
   gtk_window_set_opacity (flash_window, 1);
   gtk_widget_show_all (GTK_WIDGET (flash_window));
-  flash_priv->flash_timeout_tag = g_timeout_add (FLASH_DURATION, cheese_flash_start_fade, (gpointer)flash);
+  flash_priv->flash_timeout_tag = g_timeout_add (FLASH_DURATION, cheese_flash_start_fade, (gpointer) flash);
 }
 
-CheeseFlash*
+CheeseFlash *
 cheese_flash_new (void)
 {
   return g_object_new (CHEESE_TYPE_FLASH, NULL);
 }
-
